@@ -35,6 +35,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <netdb.h>
+#include <sys/socket.h>
 #include <net/if.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
@@ -61,6 +62,12 @@
 #include "libvncserver/ifaddr/ifaddrs.h"
 #endif
 
+#ifdef RFC2553
+#define ADDR_FAMILY_MEMBER ss_family
+#else
+#define ADDR_FAMILY_MEMBER sa_family
+#endif
+
 #define VINO_DBUS_BUS_NAME  "org.gnome.Vino"
 
 G_DEFINE_TYPE (VinoDBusListener, vino_dbus_listener, G_TYPE_OBJECT)
@@ -91,13 +98,6 @@ vino_dbus_listener_get_internal_data (VinoDBusListener *listener,
                                       gint             *port,
                                       GError           **error);
 
-static gboolean
-vino_dbus_listener_share_with_tube (VinoDBusListener *listener,
-                                    const gchar      *connection_path,
-                                    const gchar      *tube_path,
-                                    GHashTable       *properties,
-                                    GError           **error);
-
 #include "dbus-interface-glue.h"
 
 static void vino_dbus_listener_set_server (VinoDBusListener *listener,
@@ -125,7 +125,7 @@ get_local_hostname (VinoDBusListener *listener)
       if (ifa->ifa_addr == NULL || ifa->ifa_name == NULL || (ifa->ifa_flags & IFF_UP) == 0)
 	continue;
 
-      switch (ifa->ifa_addr->sa_family)
+      switch (ifa->ifa_addr->ADDR_FAMILY_MEMBER)
 	{
 	  case AF_INET:
 	    sin = &((struct sockaddr_in *)ifa->ifa_addr)->sin_addr;
@@ -325,24 +325,6 @@ vino_dbus_listener_get_internal_data (VinoDBusListener *listener,
   return TRUE;
 }
 
-static gboolean
-vino_dbus_listener_share_with_tube (VinoDBusListener *listener,
-                                    const gchar * connection_path,
-                                    const gchar * tube_path,
-                                    GHashTable * properties,
-                                    GError **error)
-{
-#ifdef HAVE_TELEPATHY_GLIB
-  return vino_tube_servers_manager_share_with_tube (listener->priv->manager,
-      connection_path, tube_path, properties, error);
-#else
-  g_set_error (error, vino_dbus_error_quark (),
-      VINO_DBUS_ERROR_NOT_IMPLEMENTED,
-      "Tubes are not installed");
-  return FALSE;
-#endif
-}
-
 static void
 vino_dbus_listener_info_changed (VinoServer *server,
                                  GParamSpec *property,
